@@ -1,14 +1,14 @@
 #!/bin/sh
 #set -x
 #=======================================================================
-# * Version: $Id: cron_daily.src,v 1.2 2014/11/13 16:36:10 nroche Exp $
+# * Version: $Id: cron_daily.src,v 1.3 2015/06/03 14:03:23 nroche Exp $
 # * Project: MediaTex
 # * Module : scripts
 # *
 # * This script is call by cron
 #
 # MediaTex is an Electronic Records Management System
-# Copyright (C) 2014  Nicolas Roche
+# Copyright (C) 2014 2015 Nicolas Roche
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,11 +28,8 @@ CACHEDIR="/var/cache/mediatex"
 BINDIR=/usr/bin
 LOGFILE=$(mktemp)
 
-SERVERS=$(ls $CACHEDIR)
-for SERVER in $SERVERS; do
-    $BINDIR/mediatex -swarning -ffile make >/dev/null 2>$LOGFILE
-    $BINDIR/mediatex -swarning -ffile motd >/etc/motd 2>>$LOGFILE
-done
+$BINDIR/mediatex -swarning -ffile make >/dev/null 2>$LOGFILE
+$BINDIR/mediatex -swarning -ffile motd >/etc/motd 2>>$LOGFILE
 
 cat $LOGFILE | sort | uniq
 rm -f $LOGFILE
