@@ -1,14 +1,14 @@
 #!/bin/sh
 #set -x
 #=======================================================================
-# * Version: $Id: cron_hourly.src,v 1.2 2014/11/13 16:36:10 nroche Exp $
+# * Version: $Id: cron_hourly.src,v 1.3 2015/06/03 14:03:23 nroche Exp $
 # * Project: MediaTex
 # * Module : scripts
 # *
 # * This script is call by cron
 #
 # MediaTex is an Electronic Records Management System
-# Copyright (C) 2014  Nicolas Roche
+# Copyright (C) 2014 2015 Nicolas Roche
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,8 +27,6 @@
 CACHEDIR="/var/cache/mediatex"
 BINDIR=/usr/bin
 
-SERVERS=$(ls $CACHEDIR)
-for SERVER in $SERVERS; do
-    $BINDIR/mediatex -swarning -ffile srv extract    
-    $BINDIR/mediatex -swarning -ffile srv notify
-done
+$BINDIR/mediatex -swarning -ffile srv extract    
+$BINDIR/mediatex -swarning -ffile srv notify
+
