@@ -1,13 +1,13 @@
 #!/bin/bash
 #=======================================================================
-# * Version: $Id: utCommand.sh,v 1.2 2014/11/13 16:36:51 nroche Exp $
+# * Version: $Id: utCommand.sh,v 1.3 2015/06/03 14:03:49 nroche Exp $
 # * Project: MediaTex
 # * Module:  miscellaneous modules
 # *
 # * Unit test script for command.c
 #
 # MediaTex is an Electronic Records Management System
-# Copyright (C) 2014  Nicolas Roche
+# Copyright (C) 2014 2015 Nicolas Roche
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 . ${srcdir}/../utMediatex.sh
 
 # run the unit test
-./utcommand -s err -X -i $srcdir/env.sh >ut.out  2>&1
+./utcommand -s err -S -i $srcdir/env.sh >ut.out  2>&1
 
 # compare with the expected output
 mrProperOutputs
