@@ -35,6 +35,97 @@
 
 GLOBAL_STRUCT_DEF_BIN;
 
+/*=======================================================================
+ * Function   : sqlString
+ * Description: replace special caracteres
+ * Synopsis   : char* sqlString(char* string)
+ * Input      : char* string : the string to rewrite
+ *              char* buffer : the buffer to use
+ * Output     : char* : a static buffer
+ =======================================================================*/
+char*
+sqlString(char* string, char* buffer)
+{
+  char* ptr = buffer;
+  int len = 0;
+  char car = 0;
+  int i;
+
+  len = strlen(string);
+
+  for (i=0; i<len; ++i) {
+    car = string[i];
+
+    switch (car) {
+    case '\'':
+      *ptr++ = car;
+      *ptr++ = car;
+      break;
+    default:
+      *ptr++ = car;
+    }
+  }
+
+  *ptr=0;
+  return buffer;
+}
+
+/*=======================================================================
+ * Function   : sqlString1
+ * Description: replace special caracteres
+ * Synopsis   : char* sqlString1(char* string)
+ * Input      : char* string : the string to rewrite
+ * Output     : char* : a static buffer
+ =======================================================================*/
+char*
+sqlString1(char* string)
+{
+  static char buffer[128];
+  return sqlString(string, buffer);
+}
+
+/*=======================================================================
+ * Function   : sqlString2
+ * Description: replace special caracteres
+ * Synopsis   : char* sqlString2(char* string)
+ * Input      : char* string : the string to rewrite
+ * Output     : char* : a static buffer
+ =======================================================================*/
+char*
+sqlString2(char* string)
+{
+  static char buffer[128];
+  return sqlString(string, buffer);
+}
+
+/*=======================================================================
+ * Function   : sqlString3
+ * Description: replace special caracteres
+ * Synopsis   : char* sqlString3(char* string)
+ * Input      : char* string : the string to rewrite
+ * Output     : char* : a static buffer
+ =======================================================================*/
+char*
+sqlString3(char* string)
+{
+  static char buffer[128];
+  return sqlString(string, buffer);
+}
+
+/*=======================================================================
+ * Function   : sqlString4
+ * Description: replace special caracteres
+ * Synopsis   : char* sqlString4(char* string)
+ * Input      : char* string : the string to rewrite
+ * Output     : char* : a static buffer
+ =======================================================================*/
+char*
+sqlString4(char* string)
+{
+  static char buffer[128];
+  return sqlString(string, buffer);
+}
+
 /*=======================================================================
  * Function   : sqlCreateTables
  * Description: create all sql tables
@@ -472,7 +563,8 @@ sqlCatalogTree(Collection* coll)
     while((category = rgNext(self->categories)) != NULL) {
       if (!getCateListUri(url, "/", category->id, 1)) goto error;
       printf("%s\n  ", i?",":"");
-      printf("  ('%s', '~%s/index%s')", category->label, coll->user, url);
+      printf("  ('%s', '~%s/index%s')", 
+	     sqlString1(category->label), coll->user, url);
       i = 1;
       if (!isEmptyRing(category->childs)) nbChilds = 1;
       if (!isEmptyRing(category->humans)) nbHums = 1;
@@ -490,7 +582,8 @@ sqlCatalogTree(Collection* coll)
       document = (Document*)node->item;
       if (!getDocumentUri(url, "/", document->id)) goto error;
       printf("%s\n  ", i?",":"");
-      printf("  ('%s', '~%s/index%s')", document->label, coll->user, url);
+      printf("  ('%s', '~%s/index%s')", 
+	     sqlString1(document->label), coll->user, url);
       i = 1;
       if (!isEmptyRing(document->archives)) nbArchs = 1;
     }
@@ -507,7 +600,9 @@ sqlCatalogTree(Collection* coll)
       if (!getHumanUri(url, "/", human->id)) goto error;
       printf("%s\n  ", i?",":"");
       printf("  ('%s', '%s', '~%s/index%s')", 
-	     human->firstName, human->secondName, coll->user, url);
+	     sqlString1(human->firstName), 
+	     sqlString2(human->secondName), 
+	     coll->user, url);
       i = 1;
     }
     printf(";\n\n");
@@ -522,7 +617,8 @@ sqlCatalogTree(Collection* coll)
     while ((role = rgNext(self->roles)) != NULL) {
       if (!getRoleListUri(url, "/", role->id, 1)) goto error;
       printf("%s\n  ", i?",":"");
-      printf("  ('%s', '~%s/index%s')", role->label, coll->user, url);
+      printf("  ('%s', '~%s/index%s')", 
+	     sqlString1(role->label), coll->user, url);
       i = 1;
       if (!isEmptyRing(role->assos)) nbAssoRole = 1;
     }
@@ -542,7 +638,7 @@ sqlCatalogTree(Collection* coll)
 	
 	printf("%s\n  ", i?",":"");
 	printf("  ('%s', '%s')", 
-	       category->label, child->label);
+	       sqlString1(category->label), child->label);
 	i = 1;
       }
     }
@@ -562,7 +658,9 @@ sqlCatalogTree(Collection* coll)
 	
 	printf("%s\n  ", i?",":"");
 	printf("  ('%s', '%s', '%s')", 
-	       category->label, human->firstName, human->secondName);
+	       sqlString1(category->label),
+	       sqlString2(human->firstName),
+	       sqlString3(human->secondName));
 	i = 1;
       }
     }
@@ -582,7 +680,8 @@ sqlCatalogTree(Collection* coll)
 	
 	printf("%s\n  ", i?",":"");
 	printf("  ('%s', '%s')", 
-	       category->label, document->label);
+	       sqlString1(category->label), 
+	       sqlString2(document->label));
 	i = 1;
       }
     }
@@ -602,7 +701,8 @@ sqlCatalogTree(Collection* coll)
 
 	printf("%s\n  ", i?",":"");
 	printf("  ('%s', '%s', '%lli')", 
-	       document->label, archive->hash, archive->size);
+	       sqlString1(document->label), 
+	       archive->hash, archive->size);
 	i = 1;
       }
     }
@@ -621,9 +721,11 @@ sqlCatalogTree(Collection* coll)
       while ((assoRole = rgNext(role->assos)) != NULL) {
 	
 	printf("%s\n  ", i?",":"");
-	printf("  ('%s', '%s', '%s', '%s')",
-	       role->label, assoRole->document->label,
-	       assoRole->human->firstName, assoRole->human->secondName);
+	printf("  ('%s', '%s', '%s', '%s')", 
+	       sqlString1(role->label), 
+	       sqlString2(assoRole->document->label),
+	       sqlString3(assoRole->human->firstName), 
+	       sqlString4(assoRole->human->secondName));
 	i = 1;
       }
     }
@@ -784,7 +886,8 @@ sqlAssoCaracs(Collection* coll)
 	printf("%s\n  ", i?",":"");
 	printf("  ('%s', '%lli', '%s', '%s')", 
 	       archive->hash, archive->size,
-	       assoCarac->carac->label, assoCarac->value);
+	       sqlString1(assoCarac->carac->label), 
+	       sqlString2(assoCarac->value));
 	i = 1;
       }
     }
@@ -805,8 +908,9 @@ sqlAssoCaracs(Collection* coll)
 			   env.confLabel, coll->label);
 	printf("%s\n  ", i?",":"");
 	printf("  ('%s', '%s', '%s')", 
-	       category->label,
-	       assoCarac->carac->label, assoCarac->value);
+	       sqlString1(category->label),
+	       sqlString2(assoCarac->carac->label), 
+	       sqlString3(assoCarac->value));
 	i = 1;
       }
     }
@@ -826,8 +930,10 @@ sqlAssoCaracs(Collection* coll)
 			   env.confLabel, coll->label);
 	printf("%s\n  ", i?",":"");
 	printf("  ('%s', '%s', '%s', '%s')", 
-	       human->firstName, human->secondName,
-	       assoCarac->carac->label, assoCarac->value);
+	       sqlString1(human->firstName), 
+	       sqlString2(human->secondName),
+	       sqlString3(assoCarac->carac->label), 
+	       sqlString4(assoCarac->value));
 	i = 1;
       }
     }
@@ -847,8 +953,9 @@ sqlAssoCaracs(Collection* coll)
 			   env.confLabel, coll->label);
 	printf("%s\n  ", i?",":"");
 	printf("  ('%s', '%s', '%s')", 
-	       document->label,
-	       assoCarac->carac->label, assoCarac->value);
+	       sqlString1(document->label),
+	       sqlString2(assoCarac->carac->label), 
+	       sqlString3(assoCarac->value));
 	i = 1;
       }
     }
